@@ -83,14 +83,14 @@ const HEIGHT: f64 = 500.0;
 
 trait PlotTrait {
     type Item;
-    fn plot_type(&self) -> PlotType;
+    fn plot_type(&self) -> PlotMetaType;
     fn write_name(&self, a: &mut dyn fmt::Write) -> fmt::Result;
     fn iter_first(&mut self) -> &mut dyn Iterator<Item = Self::Item>;
     fn iter_second(&mut self) -> &mut dyn Iterator<Item = Self::Item>;
 }
 
 struct PlotStruct<I: PlotIter, F: Display> {
-    ptype: PlotType,
+    ptype: PlotMetaType,
     iter: Option<I>,
     it1: Option<I::It1>,
     it2: Option<I::It2>,
@@ -98,7 +98,7 @@ struct PlotStruct<I: PlotIter, F: Display> {
 }
 
 impl<I: PlotIter, F: Display> PlotStruct<I, F> {
-    fn new(iter: I, func: F, ptype: PlotType) -> Self {
+    fn new(iter: I, func: F, ptype: PlotMetaType) -> Self {
         PlotStruct {
             iter: Some(iter),
             it1: None,
@@ -111,7 +111,7 @@ impl<I: PlotIter, F: Display> PlotStruct<I, F> {
 
 impl<X, Y, D: PlotIter<Item1 = (X, Y), Item2 = (X, Y)>, F: Display> PlotTrait for PlotStruct<D, F> {
     type Item = (X, Y);
-    fn plot_type(&self) -> PlotType {
+    fn plot_type(&self) -> PlotMetaType {
         self.ptype
     }
     fn write_name(&self, a: &mut dyn fmt::Write) -> fmt::Result {
@@ -136,6 +136,11 @@ enum PlotType {
     Histo,
     LineFill,
     LineFillRaw,
+}
+
+#[derive(Copy, Clone, Debug)]
+enum PlotMetaType {
+    Plot(PlotType),
     Text,
 }
 
@@ -299,6 +304,7 @@ pub struct Data<'a, X: PlotNum + 'a, Y: PlotNum + 'a> {
     ymarkers: Vec<Y>,
     num_css_classes: Option<usize>,
     preserve_aspect: bool,
+    dim: Option<[f64; 2]>,
 }
 impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Default for Data<'a, X, Y> {
     fn default() -> Self {
@@ -308,10 +314,15 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Default for Data<'a, X, Y> {
             ymarkers: vec![],
             num_css_classes: Some(8),
             preserve_aspect: false,
+            dim: None,
         }
     }
 }
 impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
+    pub fn with_dim(&mut self, x: f64, y: f64) -> &mut Self {
+        self.dim = Some([x, y]);
+        self
+    }
     pub fn xmarker(&mut self, a: X) -> &mut Self {
         self.xmarkers.push(a);
         self
@@ -333,7 +344,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
         self.plots.push(Box::new(PlotStruct::new(
             std::iter::empty(),
             name,
-            PlotType::Text,
+            PlotMetaType::Text,
         )));
         self
     }
@@ -355,7 +366,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
         self.plots.push(Box::new(PlotStruct::new(
             plots.map_plot(|x| x.make_plot(), |x| x.make_plot()),
             name,
-            PlotType::Line,
+            PlotMetaType::Plot(PlotType::Line),
         )));
         self
     }
@@ -377,7 +388,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
         self.plots.push(Box::new(PlotStruct::new(
             plots.map_plot(|x| x.make_plot(), |x| x.make_plot()),
             name,
-            PlotType::LineFill,
+            PlotMetaType::Plot(PlotType::LineFill),
         )));
         self
     }
@@ -400,7 +411,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
         self.plots.push(Box::new(PlotStruct::new(
             plots.map_plot(|x| x.make_plot(), |x| x.make_plot()),
             name,
-            PlotType::LineFillRaw,
+            PlotMetaType::Plot(PlotType::LineFillRaw),
         )));
         self
     }
@@ -424,7 +435,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
         self.plots.push(Box::new(PlotStruct::new(
             plots.map_plot(|x| x.make_plot(), |x| x.make_plot()),
             name,
-            PlotType::Scatter,
+            PlotMetaType::Plot(PlotType::Scatter),
         )));
         self
     }
@@ -447,7 +458,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
         self.plots.push(Box::new(PlotStruct::new(
             plots.map_plot(|x| x.make_plot(), |x| x.make_plot()),
             name,
-            PlotType::Histo,
+            PlotMetaType::Plot(PlotType::Histo),
         )));
         self
     }
@@ -485,6 +496,7 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
             ymarkers: vec![],
             num_css_classes: None,
             preserve_aspect: false,
+            dim: None,
         };
 
         std::mem::swap(&mut val, self);
@@ -510,10 +522,15 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Data<'a, X, Y> {
             val.ymarkers.clone(),
         );
 
-        let ideal_dash_size = 20.0;
-
-        let canvas = render::Canvas::with_options(val.preserve_aspect, val.num_css_classes);
+        let canvas = render::Canvas::with_options(
+            boundx,
+            boundy,
+            val.dim,
+            val.preserve_aspect,
+            val.num_css_classes,
+        );
 
+        let ideal_dash_size = canvas.ideal_dash_size;
         let boundx = Bound {
             min: boundx[0],
             max: boundx[1],
@@ -579,6 +596,10 @@ impl<'a, X: PlotNum + 'a, Y: PlotNum + 'a> Plotter<'a, X, Y> {
         render::Canvas::render_plots(&mut a, self)?;
         render::Canvas::render_base(&mut a, self)
     }
+
+    pub fn get_dim(&self) -> [f64; 2] {
+        self.plots.canvas.get_dim()
+    }
 }
 
 /// Shorthand for `disp_const(move |w|write!(w,...))`
